#[repr(i32)]pub enum Edition {
Show 13 variants
Unknown = 0,
Legacy = 900,
Proto2 = 998,
Proto3 = 999,
Edition2023 = 1_000,
Edition2024 = 1_001,
Unstable = 9_999,
Edition1TestOnly = 1,
Edition2TestOnly = 2,
Edition99997TestOnly = 99_997,
Edition99998TestOnly = 99_998,
Edition99999TestOnly = 99_999,
Max = 2_147_483_647,
}Variants
Unknown = 0
Legacy = 900
Proto2 = 998
Proto3 = 999
Edition2023 = 1_000
Edition2024 = 1_001
Unstable = 9_999
Edition1TestOnly = 1
Edition2TestOnly = 2
Edition99997TestOnly = 99_997
Edition99998TestOnly = 99_998
Edition99999TestOnly = 99_999
Max = 2_147_483_647
Implementations
Sourceimpl Edition
impl Edition
Sourcepub fn as_str_name(&self) -> &'static str
pub fn as_str_name(&self) -> &'static str
String value of the enum field names used in the ProtoBuf definition.
The values are not transformed in any way and thus are considered stable (if the ProtoBuf definition does not change) and safe for programmatic use.
Sourcepub fn from_str_name(value: &str) -> Option<Self>
pub fn from_str_name(value: &str) -> Option<Self>
Creates an enum from field names used in the ProtoBuf definition.