pub struct EvalContribution {Show 18 fields
pub contribution_rid: String,
pub workspace_rid: String,
pub source: i32,
pub use_case: String,
pub expected_behavior: String,
pub scenario_hint: Option<String>,
pub capability_labels: Vec<String>,
pub failure_labels: Vec<String>,
pub tags: Vec<String>,
pub owner_user_rid: String,
pub created_by_user_rid: String,
pub lifecycle: i32,
pub revision: i64,
pub latest_brief_digest: Option<String>,
pub needs_input: Option<NeedsInput>,
pub closed_reason: Option<String>,
pub created_at: Option<Timestamp>,
pub updated_at: Option<Timestamp>,
}Fields
contribution_rid: Stringworkspace_rid: Stringsource: i32use_case: Stringexpected_behavior: Stringscenario_hint: Option<String>capability_labels: Vec<String>failure_labels: Vec<String>owner_user_rid: Stringcreated_by_user_rid: Stringlifecycle: i32revision: i64latest_brief_digest: Option<String>needs_input: Option<NeedsInput>closed_reason: Option<String>created_at: Option<Timestamp>updated_at: Option<Timestamp>Implementations
Sourceimpl EvalContribution
impl EvalContribution
Sourcepub fn source(&self) -> ContributionSource
pub fn source(&self) -> ContributionSource
Returns the enum value of source, or the default if the field is set to an invalid enum value.
Sourcepub fn set_source(&mut self, value: ContributionSource)
pub fn set_source(&mut self, value: ContributionSource)
Sets source to the provided enum value.
Sourcepub fn scenario_hint(&self) -> &str
pub fn scenario_hint(&self) -> &str
Returns the value of scenario_hint, or the default value if scenario_hint is unset.
Sourcepub fn lifecycle(&self) -> ContributionLifecycle
pub fn lifecycle(&self) -> ContributionLifecycle
Returns the enum value of lifecycle, or the default if the field is set to an invalid enum value.
Sourcepub fn set_lifecycle(&mut self, value: ContributionLifecycle)
pub fn set_lifecycle(&mut self, value: ContributionLifecycle)
Sets lifecycle to the provided enum value.
Sourcepub fn latest_brief_digest(&self) -> &str
pub fn latest_brief_digest(&self) -> &str
Returns the value of latest_brief_digest, or the default value if latest_brief_digest is unset.
Sourcepub fn closed_reason(&self) -> &str
pub fn closed_reason(&self) -> &str
Returns the value of closed_reason, or the default value if closed_reason is unset.