pub struct LifecycleEvent {
pub lifecycle_event_rid: String,
pub contribution_rid: String,
pub kind: String,
pub from_lifecycle: Option<i32>,
pub to_lifecycle: Option<i32>,
pub actor_user_rid: String,
pub reason: Option<String>,
pub created_at: Option<Timestamp>,
}Fields
lifecycle_event_rid: Stringcontribution_rid: Stringkind: Stringfrom_lifecycle: Option<i32>to_lifecycle: Option<i32>actor_user_rid: Stringreason: Option<String>created_at: Option<Timestamp>Implementations
Sourceimpl LifecycleEvent
impl LifecycleEvent
Sourcepub fn from_lifecycle(&self) -> ContributionLifecycle
pub fn from_lifecycle(&self) -> ContributionLifecycle
Returns the enum value of from_lifecycle, or the default if the field is unset or set to an invalid enum value.
Sourcepub fn set_from_lifecycle(&mut self, value: ContributionLifecycle)
pub fn set_from_lifecycle(&mut self, value: ContributionLifecycle)
Sets from_lifecycle to the provided enum value.
Sourcepub fn to_lifecycle(&self) -> ContributionLifecycle
pub fn to_lifecycle(&self) -> ContributionLifecycle
Returns the enum value of to_lifecycle, or the default if the field is unset or set to an invalid enum value.
Sourcepub fn set_to_lifecycle(&mut self, value: ContributionLifecycle)
pub fn set_to_lifecycle(&mut self, value: ContributionLifecycle)
Sets to_lifecycle to the provided enum value.