pub struct SubmitMessageFeedbackRequest {
pub conversation_rid: String,
pub message_id: String,
pub vote: i32,
pub comment: Option<String>,
}Fields
conversation_rid: Stringmessage_id: Stringvote: i32comment: Option<String>Implementations
Sourceimpl SubmitMessageFeedbackRequest
impl SubmitMessageFeedbackRequest
Sourcepub fn vote(&self) -> FeedbackVote
pub fn vote(&self) -> FeedbackVote
Returns the enum value of vote, or the default if the field is set to an invalid enum value.
Sourcepub fn set_vote(&mut self, value: FeedbackVote)
pub fn set_vote(&mut self, value: FeedbackVote)
Sets vote to the provided enum value.