pub struct AssetSortOptions {
pub is_descending: bool,
pub field: Option<i32>,
pub sort_key: Option<SortKey>,
}Fields
is_descending: boolfield: Option<i32>sort_key: Option<SortKey>Implementations
Sourceimpl AssetSortOptions
impl AssetSortOptions
Sourcepub fn field(&self) -> AssetSortField
pub fn field(&self) -> AssetSortField
Returns the enum value of field, or the default if the field is unset or set to an invalid enum value.
Sourcepub fn set_field(&mut self, value: AssetSortField)
pub fn set_field(&mut self, value: AssetSortField)
Sets field to the provided enum value.