pub struct BeginRefreshResponse {
pub decision: i32,
pub encrypted_result: Option<String>,
pub lock_token: Option<String>,
}Fields
decision: i32encrypted_result: Option<String>lock_token: Option<String>Implementations
Sourceimpl BeginRefreshResponse
impl BeginRefreshResponse
Sourcepub fn decision(&self) -> RefreshCoordinationDecision
pub fn decision(&self) -> RefreshCoordinationDecision
Returns the enum value of decision, or the default if the field is set to an invalid enum value.
Sourcepub fn set_decision(&mut self, value: RefreshCoordinationDecision)
pub fn set_decision(&mut self, value: RefreshCoordinationDecision)
Sets decision to the provided enum value.
Sourcepub fn encrypted_result(&self) -> &str
pub fn encrypted_result(&self) -> &str
Returns the value of encrypted_result, or the default value if encrypted_result is unset.
Sourcepub fn lock_token(&self) -> &str
pub fn lock_token(&self) -> &str
Returns the value of lock_token, or the default value if lock_token is unset.