pub struct CheckAlert {Show 16 fields
pub rid: String,
pub check_rid: String,
pub implementation_index: Option<i32>,
pub data_review_rid: String,
pub check_evaluation_rid: String,
pub name: String,
pub autogenerated_check_title: Option<String>,
pub autogenerated_check_description: Option<String>,
pub assignee_rids: Vec<String>,
pub start: Option<Timestamp>,
pub end: Option<Timestamp>,
pub state: Option<CheckAlertState>,
pub priority: i32,
pub chart: Option<VersionedVizId>,
pub notes: Option<String>,
pub notebook: Option<String>,
}Fields
rid: Stringcheck_rid: Stringimplementation_index: Option<i32>data_review_rid: Stringcheck_evaluation_rid: Stringname: Stringautogenerated_check_title: Option<String>autogenerated_check_description: Option<String>assignee_rids: Vec<String>start: Option<Timestamp>end: Option<Timestamp>state: Option<CheckAlertState>priority: i32chart: Option<VersionedVizId>notes: Option<String>notebook: Option<String>Implementations
Sourceimpl CheckAlert
impl CheckAlert
Sourcepub fn implementation_index(&self) -> i32
pub fn implementation_index(&self) -> i32
Returns the value of implementation_index, or the default value if implementation_index is unset.
Sourcepub fn autogenerated_check_title(&self) -> &str
pub fn autogenerated_check_title(&self) -> &str
Returns the value of autogenerated_check_title, or the default value if autogenerated_check_title is unset.
Sourcepub fn autogenerated_check_description(&self) -> &str
pub fn autogenerated_check_description(&self) -> &str
Returns the value of autogenerated_check_description, or the default value if autogenerated_check_description is unset.
Sourcepub fn priority(&self) -> Priority
pub fn priority(&self) -> Priority
Returns the enum value of priority, or the default if the field is set to an invalid enum value.
Sourcepub fn set_priority(&mut self, value: Priority)
pub fn set_priority(&mut self, value: Priority)
Sets priority to the provided enum value.