pub struct CheckAlertStatusWrapper {
pub value: Option<i32>,
}Fields
value: Option<i32>Implementations
Sourceimpl CheckAlertStatusWrapper
impl CheckAlertStatusWrapper
Sourcepub fn value(&self) -> CheckAlertStatus
pub fn value(&self) -> CheckAlertStatus
Returns the enum value of value, or the default if the field is unset or set to an invalid enum value.
Sourcepub fn set_value(&mut self, value: CheckAlertStatus)
pub fn set_value(&mut self, value: CheckAlertStatus)
Sets value to the provided enum value.