pub struct SearchCheckAlertsSortOptions {
pub is_descending: bool,
pub field: i32,
}Fields
is_descending: boolfield: i32Implementations
Sourceimpl SearchCheckAlertsSortOptions
impl SearchCheckAlertsSortOptions
Sourcepub fn field(&self) -> SearchCheckAlertsSortField
pub fn field(&self) -> SearchCheckAlertsSortField
Returns the enum value of field, or the default if the field is set to an invalid enum value.
Sourcepub fn set_field(&mut self, value: SearchCheckAlertsSortField)
pub fn set_field(&mut self, value: SearchCheckAlertsSortField)
Sets field to the provided enum value.