pub struct GetDataReviewCheckMetricsResponse {Show 18 fields
pub checks_pending_execution: i32,
pub checks_executing: i32,
pub checks_passed: i32,
pub checks_with_events_pending_review: i32,
pub checks_with_events_closed_with_ignore: i32,
pub checks_with_events_closed_with_further_action: i32,
pub checks_with_events: i32,
pub checks_with_too_many_events: i32,
pub checks_failed_to_execute_pending_review: i32,
pub checks_failed_to_execute_closed_with_ignore: i32,
pub checks_failed_to_execute_closed_with_further_action: i32,
pub checks_failed_to_execute: i32,
pub checks_executed: i32,
pub checks_total: i32,
pub events_pending_review: i32,
pub events_closed_with_ignore: i32,
pub events_closed_with_further_action: i32,
pub events_total: i32,
}Fields
checks_pending_execution: i32checks_executing: i32checks_passed: i32checks_with_events_pending_review: i32checks_with_events_closed_with_ignore: i32checks_with_events_closed_with_further_action: i32checks_with_events: i32checks_with_too_many_events: i32checks_failed_to_execute_pending_review: i32checks_failed_to_execute_closed_with_ignore: i32checks_failed_to_execute_closed_with_further_action: i32checks_failed_to_execute: i32checks_executed: i32checks_total: i32events_pending_review: i32events_closed_with_ignore: i32events_closed_with_further_action: i32events_total: i32Trait Implementations
Sourceimpl Clone for GetDataReviewCheckMetricsResponse
impl Clone for GetDataReviewCheckMetricsResponse
Sourcefn clone(&self) -> GetDataReviewCheckMetricsResponse
fn clone(&self) -> GetDataReviewCheckMetricsResponse
Returns a duplicate of the value. Read more
1.0.0 (const: unstable) · Sourcefn clone_from(&mut self, source: &Self)
fn clone_from(&mut self, source: &Self)
Performs copy-assignment from
source. Read moreimpl Copy for GetDataReviewCheckMetricsResponse
Sourceimpl Message for GetDataReviewCheckMetricsResponse
impl Message for GetDataReviewCheckMetricsResponse
Sourcefn encoded_len(&self) -> usize
fn encoded_len(&self) -> usize
Returns the encoded length of the message without a length delimiter.
Sourcefn encode(&self, buf: &mut impl BufMut) -> Result<(), EncodeError>where
Self: Sized,
fn encode(&self, buf: &mut impl BufMut) -> Result<(), EncodeError>where
Self: Sized,
Encodes the message to a buffer. Read more
Sourcefn encode_to_vec(&self) -> Vec<u8> ⓘwhere
Self: Sized,
fn encode_to_vec(&self) -> Vec<u8> ⓘwhere
Self: Sized,
Encodes the message to a newly allocated buffer.
Sourcefn encode_length_delimited(
&self,
buf: &mut impl BufMut,
) -> Result<(), EncodeError>where
Self: Sized,
fn encode_length_delimited(
&self,
buf: &mut impl BufMut,
) -> Result<(), EncodeError>where
Self: Sized,
Encodes the message with a length-delimiter to a buffer. Read more
Sourcefn encode_length_delimited_to_vec(&self) -> Vec<u8> ⓘwhere
Self: Sized,
fn encode_length_delimited_to_vec(&self) -> Vec<u8> ⓘwhere
Self: Sized,
Encodes the message with a length-delimiter to a newly allocated buffer.
Sourcefn decode(buf: impl Buf) -> Result<Self, DecodeError>where
Self: Default,
fn decode(buf: impl Buf) -> Result<Self, DecodeError>where
Self: Default,
Decodes an instance of the message from a buffer. Read more
Sourcefn decode_length_delimited(buf: impl Buf) -> Result<Self, DecodeError>where
Self: Default,
fn decode_length_delimited(buf: impl Buf) -> Result<Self, DecodeError>where
Self: Default,
Decodes a length-delimited instance of the message from the buffer.
Sourcefn merge(&mut self, buf: impl Buf) -> Result<(), DecodeError>where
Self: Sized,
fn merge(&mut self, buf: impl Buf) -> Result<(), DecodeError>where
Self: Sized,
Decodes an instance of the message from a buffer, and merges it into
self. Read moreSourcefn merge_length_delimited(&mut self, buf: impl Buf) -> Result<(), DecodeError>where
Self: Sized,
fn merge_length_delimited(&mut self, buf: impl Buf) -> Result<(), DecodeError>where
Self: Sized,
Decodes a length-delimited instance of the message from buffer, and
merges it into
self.impl StructuralPartialEq for GetDataReviewCheckMetricsResponse