SearchQuery

Struct SearchQuery 

pub struct SearchQuery {
Show 39 fields pub archived: Option<bool>, pub search_text: Option<String>, pub exact_match: Option<String>, pub after: Option<Timestamp>, pub before: Option<Timestamp>, pub advanced_time_filter: Option<EventTimeFilter>, pub asset: Option<String>, pub assets: Option<AssetsFilter>, pub template: Option<String>, pub workbook: Option<String>, pub data_review: Option<String>, pub data_reviews: Option<DataReviewsFilter>, pub origin_type: Option<i32>, pub origin_types: Option<OriginTypesFilter>, pub data_review_check: Option<String>, pub data_review_checks: Option<DataReviewChecksFilter>, pub disposition_status: Option<i32>, pub disposition_statuses: Option<EventDispositionStatusListWrapper>, pub priority: Option<i32>, pub priorities: Option<PriorityListWrapper>, pub assignee: Option<String>, pub assignees: Option<AssigneesFilter>, pub event_type: Option<i32>, pub event_types: Option<EventTypeListWrapper>, pub created_by: Option<String>, pub created_by_any_of: Option<UserRidListWrapper>, pub label: Option<String>, pub labels: Option<LabelsFilter>, pub property: Option<Property>, pub properties: Option<PropertiesFilter>, pub and: Option<SearchQueryListWrapper>, pub or: Option<SearchQueryListWrapper>, pub not: Option<Box<SearchQuery>>, pub workspace: Option<String>, pub procedure: Option<String>, pub procedure_execution: Option<String>, pub step_id: Option<String>, pub streaming_checklist: Option<String>, pub streaming_check: Option<String>,
}

Fields

archived: Option<bool>search_text: Option<String>exact_match: Option<String>after: Option<Timestamp>before: Option<Timestamp>advanced_time_filter: Option<EventTimeFilter>asset: Option<String>assets: Option<AssetsFilter>template: Option<String>workbook: Option<String>data_review: Option<String>data_reviews: Option<DataReviewsFilter>origin_type: Option<i32>origin_types: Option<OriginTypesFilter>data_review_check: Option<String>data_review_checks: Option<DataReviewChecksFilter>disposition_status: Option<i32>disposition_statuses: Option<EventDispositionStatusListWrapper>priority: Option<i32>priorities: Option<PriorityListWrapper>assignee: Option<String>assignees: Option<AssigneesFilter>event_type: Option<i32>event_types: Option<EventTypeListWrapper>created_by: Option<String>created_by_any_of: Option<UserRidListWrapper>label: Option<String>labels: Option<LabelsFilter>property: Option<Property>properties: Option<PropertiesFilter>and: Option<SearchQueryListWrapper>or: Option<SearchQueryListWrapper>not: Option<Box<SearchQuery>>workspace: Option<String>procedure: Option<String>procedure_execution: Option<String>step_id: Option<String>streaming_checklist: Option<String>streaming_check: Option<String>

Implementations

Source

impl SearchQuery

pub fn archived(&self) -> bool

Returns the value of archived, or the default value if archived is unset.

pub fn search_text(&self) -> &str

Returns the value of search_text, or the default value if search_text is unset.

pub fn exact_match(&self) -> &str

Returns the value of exact_match, or the default value if exact_match is unset.

pub fn asset(&self) -> &str

Returns the value of asset, or the default value if asset is unset.

pub fn template(&self) -> &str

Returns the value of template, or the default value if template is unset.

pub fn workbook(&self) -> &str

Returns the value of workbook, or the default value if workbook is unset.

pub fn data_review(&self) -> &str

Returns the value of data_review, or the default value if data_review is unset.

pub fn origin_type(&self) -> SearchEventOriginType

Returns the enum value of origin_type, or the default if the field is unset or set to an invalid enum value.

pub fn set_origin_type(&mut self, value: SearchEventOriginType)

Sets origin_type to the provided enum value.

pub fn data_review_check(&self) -> &str

Returns the value of data_review_check, or the default value if data_review_check is unset.

pub fn disposition_status(&self) -> EventDispositionStatus

Returns the enum value of disposition_status, or the default if the field is unset or set to an invalid enum value.

pub fn set_disposition_status(&mut self, value: EventDispositionStatus)

Sets disposition_status to the provided enum value.

pub fn priority(&self) -> Priority

Returns the enum value of priority, or the default if the field is unset or set to an invalid enum value.

pub fn set_priority(&mut self, value: Priority)

Sets priority to the provided enum value.

pub fn assignee(&self) -> &str

Returns the value of assignee, or the default value if assignee is unset.

pub fn event_type(&self) -> EventType

Returns the enum value of event_type, or the default if the field is unset or set to an invalid enum value.

pub fn set_event_type(&mut self, value: EventType)

Sets event_type to the provided enum value.

pub fn created_by(&self) -> &str

Returns the value of created_by, or the default value if created_by is unset.

pub fn label(&self) -> &str

Returns the value of label, or the default value if label is unset.

pub fn workspace(&self) -> &str

Returns the value of workspace, or the default value if workspace is unset.

pub fn procedure(&self) -> &str

Returns the value of procedure, or the default value if procedure is unset.

pub fn procedure_execution(&self) -> &str

Returns the value of procedure_execution, or the default value if procedure_execution is unset.

pub fn step_id(&self) -> &str

Returns the value of step_id, or the default value if step_id is unset.

pub fn streaming_checklist(&self) -> &str

Returns the value of streaming_checklist, or the default value if streaming_checklist is unset.

pub fn streaming_check(&self) -> &str

Returns the value of streaming_check, or the default value if streaming_check is unset.