#[repr(i32)]pub enum FileStoreCommonError {
Unspecified = 0,
DriveNotFound = 1,
FileNotFound = 2,
FileRevisionNotFound = 3,
PermissionDenied = 4,
}Variants
Implementations
Sourceimpl FileStoreCommonError
impl FileStoreCommonError
Sourcepub fn is_valid(value: i32) -> bool
pub fn is_valid(value: i32) -> bool
Returns true if value is a variant of FileStoreCommonError.
Sourcepub fn from_i32(value: i32) -> Option<FileStoreCommonError>
👎Deprecated: Use the TryFrom<i32> implementation instead
pub fn from_i32(value: i32) -> Option<FileStoreCommonError>
Use the TryFrom<i32> implementation instead
Converts an i32 to a FileStoreCommonError, or None if value is not a valid variant.
Sourceimpl FileStoreCommonError
impl FileStoreCommonError
Sourcepub fn as_str_name(&self) -> &'static str
pub fn as_str_name(&self) -> &'static str
String value of the enum field names used in the ProtoBuf definition.
The values are not transformed in any way and thus are considered stable (if the ProtoBuf definition does not change) and safe for programmatic use.
Sourcepub fn from_str_name(value: &str) -> Option<Self>
pub fn from_str_name(value: &str) -> Option<Self>
Creates an enum from field names used in the ProtoBuf definition.