pub struct FileChangeFailure {
pub code: i32,
pub message: String,
}Fields
code: i32message: StringImplementations
Sourceimpl FileChangeFailure
impl FileChangeFailure
Sourcepub fn code(&self) -> FileStoreError
pub fn code(&self) -> FileStoreError
Returns the enum value of code, or the default if the field is set to an invalid enum value.
Sourcepub fn set_code(&mut self, value: FileStoreError)
pub fn set_code(&mut self, value: FileStoreError)
Sets code to the provided enum value.