pub struct ContainerizedExtractor {
pub rid: String,
pub workspace_rid: String,
pub name: String,
pub description: Option<String>,
pub created_at: Option<Timestamp>,
pub is_archived: bool,
pub active_container_image: Option<ContainerImage>,
pub origin: i32,
pub catalog_id: Option<String>,
}Fields
rid: Stringworkspace_rid: Stringname: Stringdescription: Option<String>created_at: Option<Timestamp>is_archived: boolactive_container_image: Option<ContainerImage>origin: i32catalog_id: Option<String>Implementations
Sourceimpl ContainerizedExtractor
impl ContainerizedExtractor
Sourcepub fn description(&self) -> &str
pub fn description(&self) -> &str
Returns the value of description, or the default value if description is unset.
Sourcepub fn origin(&self) -> ExtractorOrigin
pub fn origin(&self) -> ExtractorOrigin
Returns the enum value of origin, or the default if the field is set to an invalid enum value.
Sourcepub fn set_origin(&mut self, value: ExtractorOrigin)
pub fn set_origin(&mut self, value: ExtractorOrigin)
Sets origin to the provided enum value.
Sourcepub fn catalog_id(&self) -> &str
pub fn catalog_id(&self) -> &str
Returns the value of catalog_id, or the default value if catalog_id is unset.