pub struct DecryptedSecret {
pub rid: String,
pub name: String,
pub description: String,
pub decrypted_value: String,
pub created_by: String,
pub properties: HashMap<String, String>,
pub labels: Vec<String>,
pub created_at: Option<Timestamp>,
pub is_archived: bool,
}Fields
rid: Stringname: Stringdescription: Stringdecrypted_value: Stringcreated_by: Stringproperties: HashMap<String, String>labels: Vec<String>created_at: Option<Timestamp>is_archived: boolTrait Implementations
Sourceimpl Clone for DecryptedSecret
impl Clone for DecryptedSecret
Sourcefn clone(&self) -> DecryptedSecret
fn clone(&self) -> DecryptedSecret
Returns a duplicate of the value. Read more
1.0.0 (const: unstable) · Sourcefn clone_from(&mut self, source: &Self)
fn clone_from(&mut self, source: &Self)
Performs copy-assignment from
source. Read moreSourceimpl Debug for DecryptedSecret
impl Debug for DecryptedSecret
Sourceimpl Default for DecryptedSecret
impl Default for DecryptedSecret
Sourceimpl Message for DecryptedSecret
impl Message for DecryptedSecret
Sourcefn encoded_len(&self) -> usize
fn encoded_len(&self) -> usize
Returns the encoded length of the message without a length delimiter.
Sourcefn encode(&self, buf: &mut impl BufMut) -> Result<(), EncodeError>where
Self: Sized,
fn encode(&self, buf: &mut impl BufMut) -> Result<(), EncodeError>where
Self: Sized,
Encodes the message to a buffer. Read more
Sourcefn encode_to_vec(&self) -> Vec<u8> ⓘwhere
Self: Sized,
fn encode_to_vec(&self) -> Vec<u8> ⓘwhere
Self: Sized,
Encodes the message to a newly allocated buffer.
Sourcefn encode_length_delimited(
&self,
buf: &mut impl BufMut,
) -> Result<(), EncodeError>where
Self: Sized,
fn encode_length_delimited(
&self,
buf: &mut impl BufMut,
) -> Result<(), EncodeError>where
Self: Sized,
Encodes the message with a length-delimiter to a buffer. Read more
Sourcefn encode_length_delimited_to_vec(&self) -> Vec<u8> ⓘwhere
Self: Sized,
fn encode_length_delimited_to_vec(&self) -> Vec<u8> ⓘwhere
Self: Sized,
Encodes the message with a length-delimiter to a newly allocated buffer.
Sourcefn decode(buf: impl Buf) -> Result<Self, DecodeError>where
Self: Default,
fn decode(buf: impl Buf) -> Result<Self, DecodeError>where
Self: Default,
Decodes an instance of the message from a buffer. Read more
Sourcefn decode_length_delimited(buf: impl Buf) -> Result<Self, DecodeError>where
Self: Default,
fn decode_length_delimited(buf: impl Buf) -> Result<Self, DecodeError>where
Self: Default,
Decodes a length-delimited instance of the message from the buffer.
Sourcefn merge(&mut self, buf: impl Buf) -> Result<(), DecodeError>where
Self: Sized,
fn merge(&mut self, buf: impl Buf) -> Result<(), DecodeError>where
Self: Sized,
Decodes an instance of the message from a buffer, and merges it into
self. Read moreSourcefn merge_length_delimited(&mut self, buf: impl Buf) -> Result<(), DecodeError>where
Self: Sized,
fn merge_length_delimited(&mut self, buf: impl Buf) -> Result<(), DecodeError>where
Self: Sized,
Decodes a length-delimited instance of the message from buffer, and
merges it into
self.Sourceimpl PartialEq for DecryptedSecret
impl PartialEq for DecryptedSecret
Sourcefn eq(&self, other: &DecryptedSecret) -> bool
fn eq(&self, other: &DecryptedSecret) -> bool
Tests for
self and other values to be equal, and is used by ==.impl StructuralPartialEq for DecryptedSecret