pub struct DriveIndexJob {
pub drive_index_job_rid: String,
pub drive_rid: String,
pub state: i32,
pub completed_source_count: u64,
pub successful_chunk_count: u64,
pub sources: Vec<DriveIndexSourceExecution>,
pub sources_truncated: bool,
}Fields
drive_index_job_rid: Stringdrive_rid: Stringstate: i32completed_source_count: u64successful_chunk_count: u64sources: Vec<DriveIndexSourceExecution>sources_truncated: boolImplementations
Sourceimpl DriveIndexJob
impl DriveIndexJob
Sourcepub fn state(&self) -> DriveIndexJobState
pub fn state(&self) -> DriveIndexJobState
Returns the enum value of state, or the default if the field is set to an invalid enum value.
Sourcepub fn set_state(&mut self, value: DriveIndexJobState)
pub fn set_state(&mut self, value: DriveIndexJobState)
Sets state to the provided enum value.