pub struct SearchMetadataRequest {
pub resource_types: Vec<i32>,
pub workspaces: Vec<String>,
pub search_text: Option<String>,
pub page_size: Option<i32>,
pub page_token: Option<String>,
pub sort_by: i32,
pub descending: Option<bool>,
}Fields
resource_types: Vec<i32>workspaces: Vec<String>search_text: Option<String>page_size: Option<i32>page_token: Option<String>sort_by: i32descending: Option<bool>Implementations
Sourceimpl SearchMetadataRequest
impl SearchMetadataRequest
Sourcepub fn resource_types(
&self,
) -> FilterMap<Cloned<Iter<'_, i32>>, fn(i32) -> Option<ResourceType>>
pub fn resource_types( &self, ) -> FilterMap<Cloned<Iter<'_, i32>>, fn(i32) -> Option<ResourceType>>
Returns an iterator which yields the valid enum values contained in resource_types.
Sourcepub fn push_resource_types(&mut self, value: ResourceType)
pub fn push_resource_types(&mut self, value: ResourceType)
Appends the provided enum value to resource_types.
Sourcepub fn search_text(&self) -> &str
pub fn search_text(&self) -> &str
Returns the value of search_text, or the default value if search_text is unset.
Sourcepub fn page_size(&self) -> i32
pub fn page_size(&self) -> i32
Returns the value of page_size, or the default value if page_size is unset.
Sourcepub fn page_token(&self) -> &str
pub fn page_token(&self) -> &str
Returns the value of page_token, or the default value if page_token is unset.
Sourcepub fn sort_by(&self) -> MetadataSortField
pub fn sort_by(&self) -> MetadataSortField
Returns the enum value of sort_by, or the default if the field is set to an invalid enum value.
Sourcepub fn set_sort_by(&mut self, value: MetadataSortField)
pub fn set_sort_by(&mut self, value: MetadataSortField)
Sets sort_by to the provided enum value.
Sourcepub fn descending(&self) -> bool
pub fn descending(&self) -> bool
Returns the value of descending, or the default value if descending is unset.