pub struct Objective {
pub id: String,
pub name: String,
pub creator: String,
pub created_at: Option<Timestamp>,
pub priority: i32,
pub milestone_ids: Vec<String>,
pub description: Option<String>,
pub details: Option<ObjectiveDetails>,
pub status: Option<ObjectiveStatus>,
}Fields
id: Stringname: Stringcreator: Stringcreated_at: Option<Timestamp>priority: i32milestone_ids: Vec<String>description: Option<String>details: Option<ObjectiveDetails>status: Option<ObjectiveStatus>Implementations
Sourceimpl Objective
impl Objective
Sourcepub fn priority(&self) -> Priority
pub fn priority(&self) -> Priority
Returns the enum value of priority, or the default if the field is set to an invalid enum value.
Sourcepub fn set_priority(&mut self, value: Priority)
pub fn set_priority(&mut self, value: Priority)
Sets priority to the provided enum value.
Sourcepub fn description(&self) -> &str
pub fn description(&self) -> &str
Returns the value of description, or the default value if description is unset.