pub struct PlanSortOptions {
pub field: i32,
pub is_descending: bool,
}Fields
field: i32is_descending: boolImplementations
Sourceimpl PlanSortOptions
impl PlanSortOptions
Sourcepub fn field(&self) -> PlanSortField
pub fn field(&self) -> PlanSortField
Returns the enum value of field, or the default if the field is set to an invalid enum value.
Sourcepub fn set_field(&mut self, value: PlanSortField)
pub fn set_field(&mut self, value: PlanSortField)
Sets field to the provided enum value.