pub struct UpdatePlanMetadataRequest {
pub plan_rid: String,
pub title: Option<String>,
pub description: Option<String>,
pub labels: Option<LabelUpdateWrapper>,
pub properties: Option<PropertyUpdateWrapper>,
pub is_archived: Option<bool>,
pub is_published: Option<bool>,
}Fields
plan_rid: Stringtitle: Option<String>description: Option<String>labels: Option<LabelUpdateWrapper>properties: Option<PropertyUpdateWrapper>is_archived: Option<bool>is_published: Option<bool>Implementations
Sourceimpl UpdatePlanMetadataRequest
impl UpdatePlanMetadataRequest
Sourcepub fn title(&self) -> &str
pub fn title(&self) -> &str
Returns the value of title, or the default value if title is unset.
Sourcepub fn description(&self) -> &str
pub fn description(&self) -> &str
Returns the value of description, or the default value if description is unset.
Sourcepub fn is_archived(&self) -> bool
pub fn is_archived(&self) -> bool
Returns the value of is_archived, or the default value if is_archived is unset.
Sourcepub fn is_published(&self) -> bool
pub fn is_published(&self) -> bool
Returns the value of is_published, or the default value if is_published is unset.