pub struct ChannelCaptureFailed {
pub started_at: Option<Timestamp>,
pub failed_at: Option<Timestamp>,
pub reason: i32,
pub error_message: String,
}Fields
started_at: Option<Timestamp>failed_at: Option<Timestamp>reason: i32error_message: StringImplementations
Sourceimpl ChannelCaptureFailed
impl ChannelCaptureFailed
Sourcepub fn reason(&self) -> ChannelCaptureFailureReason
pub fn reason(&self) -> ChannelCaptureFailureReason
Returns the enum value of reason, or the default if the field is set to an invalid enum value.
Sourcepub fn set_reason(&mut self, value: ChannelCaptureFailureReason)
pub fn set_reason(&mut self, value: ChannelCaptureFailureReason)
Sets reason to the provided enum value.