pub struct ProcedureExecutionState {
pub global_fields: HashMap<String, FieldOutput>,
pub nodes: HashMap<String, ProcedureExecutionNode>,
pub section_edges: HashMap<String, NodeList>,
pub step_edges: HashMap<String, NodeList>,
}Fields
global_fields: HashMap<String, FieldOutput>nodes: HashMap<String, ProcedureExecutionNode>section_edges: HashMap<String, NodeList>step_edges: HashMap<String, NodeList>Trait Implementations
Sourceimpl Clone for ProcedureExecutionState
impl Clone for ProcedureExecutionState
Sourcefn clone(&self) -> ProcedureExecutionState
fn clone(&self) -> ProcedureExecutionState
Returns a duplicate of the value. Read more
1.0.0 (const: unstable) · Sourcefn clone_from(&mut self, source: &Self)
fn clone_from(&mut self, source: &Self)
Performs copy-assignment from
source. Read moreSourceimpl Debug for ProcedureExecutionState
impl Debug for ProcedureExecutionState
Sourceimpl Default for ProcedureExecutionState
impl Default for ProcedureExecutionState
Sourceimpl Message for ProcedureExecutionState
impl Message for ProcedureExecutionState
Sourcefn encoded_len(&self) -> usize
fn encoded_len(&self) -> usize
Returns the encoded length of the message without a length delimiter.
Sourcefn encode(&self, buf: &mut impl BufMut) -> Result<(), EncodeError>where
Self: Sized,
fn encode(&self, buf: &mut impl BufMut) -> Result<(), EncodeError>where
Self: Sized,
Encodes the message to a buffer. Read more
Sourcefn encode_to_vec(&self) -> Vec<u8> ⓘwhere
Self: Sized,
fn encode_to_vec(&self) -> Vec<u8> ⓘwhere
Self: Sized,
Encodes the message to a newly allocated buffer.
Sourcefn encode_length_delimited(
&self,
buf: &mut impl BufMut,
) -> Result<(), EncodeError>where
Self: Sized,
fn encode_length_delimited(
&self,
buf: &mut impl BufMut,
) -> Result<(), EncodeError>where
Self: Sized,
Encodes the message with a length-delimiter to a buffer. Read more
Sourcefn encode_length_delimited_to_vec(&self) -> Vec<u8> ⓘwhere
Self: Sized,
fn encode_length_delimited_to_vec(&self) -> Vec<u8> ⓘwhere
Self: Sized,
Encodes the message with a length-delimiter to a newly allocated buffer.
Sourcefn decode(buf: impl Buf) -> Result<Self, DecodeError>where
Self: Default,
fn decode(buf: impl Buf) -> Result<Self, DecodeError>where
Self: Default,
Decodes an instance of the message from a buffer. Read more
Sourcefn decode_length_delimited(buf: impl Buf) -> Result<Self, DecodeError>where
Self: Default,
fn decode_length_delimited(buf: impl Buf) -> Result<Self, DecodeError>where
Self: Default,
Decodes a length-delimited instance of the message from the buffer.
Sourcefn merge(&mut self, buf: impl Buf) -> Result<(), DecodeError>where
Self: Sized,
fn merge(&mut self, buf: impl Buf) -> Result<(), DecodeError>where
Self: Sized,
Decodes an instance of the message from a buffer, and merges it into
self. Read moreSourcefn merge_length_delimited(&mut self, buf: impl Buf) -> Result<(), DecodeError>where
Self: Sized,
fn merge_length_delimited(&mut self, buf: impl Buf) -> Result<(), DecodeError>where
Self: Sized,
Decodes a length-delimited instance of the message from buffer, and
merges it into
self.Sourceimpl PartialEq for ProcedureExecutionState
impl PartialEq for ProcedureExecutionState
Sourcefn eq(&self, other: &ProcedureExecutionState) -> bool
fn eq(&self, other: &ProcedureExecutionState) -> bool
Tests for
self and other values to be equal, and is used by ==.impl StructuralPartialEq for ProcedureExecutionState