pub struct ChannelValidationSuccessCondition {
pub channel: Option<ChannelLocator>,
pub comparator: i32,
pub threshold: f64,
pub timeout_millis: i32,
pub point_persistence: Option<u32>,
pub time_persistence: Option<u32>,
pub channel_captures: Vec<ChannelCaptureConfig>,
}Fields
channel: Option<ChannelLocator>comparator: i32threshold: f64timeout_millis: i32point_persistence: Option<u32>time_persistence: Option<u32>channel_captures: Vec<ChannelCaptureConfig>Implementations
Sourceimpl ChannelValidationSuccessCondition
impl ChannelValidationSuccessCondition
Sourcepub fn comparator(&self) -> Comparator
pub fn comparator(&self) -> Comparator
Returns the enum value of comparator, or the default if the field is set to an invalid enum value.
Sourcepub fn set_comparator(&mut self, value: Comparator)
pub fn set_comparator(&mut self, value: Comparator)
Sets comparator to the provided enum value.
Sourcepub fn point_persistence(&self) -> u32
pub fn point_persistence(&self) -> u32
Returns the value of point_persistence, or the default value if point_persistence is unset.
Sourcepub fn time_persistence(&self) -> u32
pub fn time_persistence(&self) -> u32
Returns the value of time_persistence, or the default value if time_persistence is unset.