pub struct SearchSecretsRequest {
pub query: Option<SearchSecretsQuery>,
pub page_size: Option<i32>,
pub sort: Option<SortOptions>,
pub token: Option<String>,
pub archived_statuses: Vec<i32>,
}Fields
query: Option<SearchSecretsQuery>page_size: Option<i32>sort: Option<SortOptions>token: Option<String>archived_statuses: Vec<i32>Implementations
Sourceimpl SearchSecretsRequest
impl SearchSecretsRequest
Sourcepub fn page_size(&self) -> i32
pub fn page_size(&self) -> i32
Returns the value of page_size, or the default value if page_size is unset.
Sourcepub fn token(&self) -> &str
pub fn token(&self) -> &str
Returns the value of token, or the default value if token is unset.
Sourcepub fn archived_statuses(
&self,
) -> FilterMap<Cloned<Iter<'_, i32>>, fn(i32) -> Option<ArchivedStatus>>
pub fn archived_statuses( &self, ) -> FilterMap<Cloned<Iter<'_, i32>>, fn(i32) -> Option<ArchivedStatus>>
Returns an iterator which yields the valid enum values contained in archived_statuses.
Sourcepub fn push_archived_statuses(&mut self, value: ArchivedStatus)
pub fn push_archived_statuses(&mut self, value: ArchivedStatus)
Appends the provided enum value to archived_statuses.