pub struct SqlQueryLogEvent {
pub query_id: String,
pub event_type: i32,
pub workspace_rid: String,
pub user_rid: String,
pub backends: Vec<i32>,
pub status: Option<i32>,
pub query_text: String,
pub event_time: Option<Timestamp>,
pub started_at: Option<Timestamp>,
pub finished_at: Option<Timestamp>,
pub duration_ms: Option<i64>,
}Fields
query_id: Stringevent_type: i32workspace_rid: Stringuser_rid: Stringbackends: Vec<i32>status: Option<i32>query_text: Stringevent_time: Option<Timestamp>started_at: Option<Timestamp>finished_at: Option<Timestamp>duration_ms: Option<i64>Implementations
Sourceimpl SqlQueryLogEvent
impl SqlQueryLogEvent
Sourcepub fn event_type(&self) -> SqlQueryEventType
pub fn event_type(&self) -> SqlQueryEventType
Returns the enum value of event_type, or the default if the field is set to an invalid enum value.
Sourcepub fn set_event_type(&mut self, value: SqlQueryEventType)
pub fn set_event_type(&mut self, value: SqlQueryEventType)
Sets event_type to the provided enum value.
Sourcepub fn backends(
&self,
) -> FilterMap<Cloned<Iter<'_, i32>>, fn(i32) -> Option<SqlQueryBackend>>
pub fn backends( &self, ) -> FilterMap<Cloned<Iter<'_, i32>>, fn(i32) -> Option<SqlQueryBackend>>
Returns an iterator which yields the valid enum values contained in backends.
Sourcepub fn push_backends(&mut self, value: SqlQueryBackend)
pub fn push_backends(&mut self, value: SqlQueryBackend)
Appends the provided enum value to backends.
Sourcepub fn status(&self) -> SqlQueryStatus
pub fn status(&self) -> SqlQueryStatus
Returns the enum value of status, or the default if the field is unset or set to an invalid enum value.
Sourcepub fn set_status(&mut self, value: SqlQueryStatus)
pub fn set_status(&mut self, value: SqlQueryStatus)
Sets status to the provided enum value.
Sourcepub fn duration_ms(&self) -> i64
pub fn duration_ms(&self) -> i64
Returns the value of duration_ms, or the default value if duration_ms is unset.