pub struct NumericPropertyPredicate {
pub name: String,
pub value: f64,
pub operator: i32,
}Fields
name: Stringvalue: f64operator: i32Implementations
Sourceimpl NumericPropertyPredicate
impl NumericPropertyPredicate
Sourcepub fn operator(&self) -> PropertyComparisonOperator
pub fn operator(&self) -> PropertyComparisonOperator
Returns the enum value of operator, or the default if the field is set to an invalid enum value.
Sourcepub fn set_operator(&mut self, value: PropertyComparisonOperator)
pub fn set_operator(&mut self, value: PropertyComparisonOperator)
Sets operator to the provided enum value.