pub struct NumericPropertyRangePredicate {
pub name: String,
pub min: Option<f64>,
pub max: Option<f64>,
pub operator: i32,
}Fields
name: Stringmin: Option<f64>max: Option<f64>operator: i32Implementations
Sourceimpl NumericPropertyRangePredicate
impl NumericPropertyRangePredicate
Sourcepub fn operator(&self) -> NumericPropertyRangeOperator
pub fn operator(&self) -> NumericPropertyRangeOperator
Returns the enum value of operator, or the default if the field is set to an invalid enum value.
Sourcepub fn set_operator(&mut self, value: NumericPropertyRangeOperator)
pub fn set_operator(&mut self, value: NumericPropertyRangeOperator)
Sets operator to the provided enum value.